@@ -43,21 +43,21 @@ class AZlyrics(Requester):
             lyrics (str): Lyrics of the detected song
         """
 
-        if not self.artist + self.title:
-            raise ValueError("Both artist and title can't be empty!")
-        
         # Best cooldown is 5 sec
         time.sleep(sleep)
 
         link = url
 
         if not url:
+            # v3.0.5: No need for artist and title if url is found
+            if not self.artist + self.title:
+                raise ValueError("Both artist and title can't be empty!")
             if self.search_engine:
                 # If user can't remember the artist,
                 # he can search by title only
                 
                 # Get AZlyrics url via Google Search
-                link = GoogleGet(
+                link = googleGet(
                             self.search_engine,
                             self.accuracy,
                             self.get,
@@ -69,7 +69,7 @@ class AZlyrics(Requester):
             else:
                 # Sometimes search engines block you
                 # If happened use the normal get method
-                link = NormalGet(
+                link = normalGet(
                             self.artist,
                             self.title,
                             0)
@@ -86,7 +86,7 @@ class AZlyrics(Requester):
         self.artist = filtr(metadata[0][:-7], True)
         self.title = filtr(metadata[1][1:-1], True)
 
-        lyrics = ParseLyric(page)
+        lyrics = parseLyric(page)
         self.lyrics = lyrics.strip()
 
         # Saving Lyrics
@@ -130,7 +130,7 @@ class AZlyrics(Requester):
         time.sleep(sleep)
         
         if self.search_engine:
-            link = GoogleGet(
+            link = googleGet(
                         self.search_engine,
                         self.accuracy,
                         self.get,
@@ -140,7 +140,7 @@ class AZlyrics(Requester):
             if not link:
                 return {}
         else:
-            link = NormalGet(
+            link = normalGet(
                         self.artist,
                         '',
                         1)
@@ -151,5 +151,5 @@ class AZlyrics(Requester):
             return {}
         
         # Store songs for later usage
-        self.songs = ParseSongs(albums_page)
+        self.songs = parseSongs(albums_page)
         return self.songs
\ No newline at end of file
